==> jc-1.4.0.tar.gz: soot/options/SETOptions.h <==
// public class soot.options.SETOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 608cfcddf2720e73 soot_options_SETOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SETOptions_H_
#define _JC_soot_options_SETOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SETOptions$sub_refs	_jc_soot_options_SETOptions$sub_refs;
typedef struct _jc_soot_options_SETOptions$sub_nonrefs	_jc_soot_options_SETOptions$sub_nonrefs;
typedef struct _jc_soot_options_SETOptions$refs	_jc_soot_options_SETOptions$refs;
typedef struct _jc_soot_options_SETOptions$nonrefs	_jc_soot_options_SETOptions$nonrefs;
typedef struct _jc_soot_options_SETOptions$object	_jc_soot_options_SETOptions$object;

typedef const struct _jc_soot_options_SETOptions$vmethods	_jc_soot_options_SETOptions$vmethods;
typedef const struct _jc_soot_options_SETOptions$vtable	_jc_soot_options_SETOptions$vtable;
typedef const struct _jc_soot_options_SETOptions$vtype	_jc_soot_options_SETOptions$vtype;

// Constructors
extern void _jc_soot_options_SETOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SETOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SETOptions$object *);
extern jboolean _jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51(_jc_env *, struct _jc_soot_options_SETOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51;

// Virtual methods structure
struct _jc_soot_options_SETOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SETOptions$object *);
	jboolean	(*naive$8deba6a4c489ca51)(_jc_env *, struct _jc_soot_options_SETOptions$object *);
};

// Vtable
struct _jc_soot_options_SETOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SETOptions$vmethods	soot_options_SETOptions;
};

// Vtype
struct _jc_soot_options_SETOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SETOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SETOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SETOptions$refs {
    _jc_soot_options_SETOptions$sub_refs	soot_options_SETOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SETOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SETOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SETOptions$sub_nonrefs	soot_options_SETOptions;
};

// Object instance structure
struct _jc_soot_options_SETOptions$object {
	_jc_soot_options_SETOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SETOptions$vtype	*vtype;
	_jc_soot_options_SETOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SETOptions$vtype _jc_soot_options_SETOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SETOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SETOptions$class_object;

#endif	/* _JC_soot_options_SETOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/SETOptions.h <==
// public class soot.options.SETOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 608cfcddf2720e73 soot_options_SETOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SETOptions_H_
#define _JC_soot_options_SETOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SETOptions$sub_refs	_jc_soot_options_SETOptions$sub_refs;
typedef struct _jc_soot_options_SETOptions$sub_nonrefs	_jc_soot_options_SETOptions$sub_nonrefs;
typedef struct _jc_soot_options_SETOptions$refs	_jc_soot_options_SETOptions$refs;
typedef struct _jc_soot_options_SETOptions$nonrefs	_jc_soot_options_SETOptions$nonrefs;
typedef struct _jc_soot_options_SETOptions$object	_jc_soot_options_SETOptions$object;

typedef const struct _jc_soot_options_SETOptions$vmethods	_jc_soot_options_SETOptions$vmethods;
typedef const struct _jc_soot_options_SETOptions$vtable	_jc_soot_options_SETOptions$vtable;
typedef const struct _jc_soot_options_SETOptions$vtype	_jc_soot_options_SETOptions$vtype;

// Constructors
extern void _jc_soot_options_SETOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SETOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_SETOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SETOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SETOptions$method$naive$8deba6a4c489ca51(_jc_env *, struct _jc_soot_options_SETOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_SETOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SETOptions$method_info$naive$8deba6a4c489ca51;

// Virtual methods structure
struct _jc_soot_options_SETOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SETOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*naive$8deba6a4c489ca51)(_jc_env *, struct _jc_soot_options_SETOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_SETOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SETOptions$vmethods	soot_options_SETOptions;
};

// Vtype
struct _jc_soot_options_SETOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SETOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SETOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SETOptions$refs {
    _jc_soot_options_SETOptions$sub_refs	soot_options_SETOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SETOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SETOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SETOptions$sub_nonrefs	soot_options_SETOptions;
};

// Object instance structure
struct _jc_soot_options_SETOptions$object {
	_jc_soot_options_SETOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SETOptions$vtype	*vtype;
	_jc_soot_options_SETOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SETOptions$vtype _jc_soot_options_SETOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SETOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SETOptions$class_object;

#endif	/* _JC_soot_options_SETOptions_H_ */
